@@ -30,6 +30,7 @@ void on_main_menu_exptel_activate (GtkMenuItem *, gpointer );
 void on_main_menu_savepad_activate (GtkMenuItem *, gpointer  );
 void on_main_menu_clearpad_activate(GtkMenuItem *, gpointer  );
 void on_main_menu_quit_activate    (GtkMenuItem *, gpointer  );
+void on_main_menu_destroy_activate   (GtkWidget  * , gpointer );
 void on_main_menu_about_activate   (GtkMenuItem *, gpointer  );
 void on_main_menu_run_activate     (GtkMenuItem *, gpointer  );
 void * start_computation(void); /* starts fortran computation in a separate thread */
@@ -40,7 +41,9 @@ void on_main_menu_view_matrix_activate(GtkMenuItem *, gpointer);
 void on_main_menu_view_pi_activate(GtkMenuItem *, gpointer );
 void on_main_menu_help_activate    (GtkMenuItem *, gpointer  );
 void on_about_closebutton_clicked  (GtkButton   *, gpointer  );
+void on_about_destroy_activate   (GtkWidget *, gpointer );
 void on_help_closebutton_clicked   (GtkButton   *, gpointer  );
+void on_help_destroy_activate   (GtkWidget *, gpointer );
 void on_cancel_button_fs1_clicked      (GtkButton   *, gpointer  );
 void on_ok_button_fs1_clicked  (GtkButton   *, gpointer  );
 void on_main_menu_quit_enter       (GtkMenuItem *, gpointer  );
@@ -100,6 +103,7 @@ void on_main_menu_options_parameters_fi (GtkMenuItem *, gpointer );
 void on_main_menu_options_parameters_is (GtkMenuItem *, gpointer );
 void on_main_menu_options_parameters_reset (GtkMenuItem *, gpointer );
 void on_examples_quit_activate    (GtkButton *, gpointer  );
+void on_examples_destroy_activate (GtkWidget  *ww, gpointer data);
 void on_examples_ok_activate    (GtkButton *, gpointer  );
 void on_dimension_m_entry_changed  (GtkEntry *, gpointer );
 void on_dimension_n_entry_changed  (GtkEntry *, gpointer );
@@ -112,12 +116,14 @@ void on_examples_beta_activate(GtkEntry *, gpointer );
 void on_examples_beta_change(GtkEntry *, gpointer );
 void on_examples_beta_e_change(GtkEntry *, gpointer );
 void on_parameters_quit_activate (GtkButton *, gpointer);
+void on_parameters_destroy_activate (GtkWidget  *ww, gpointer data);
 void on_parameters_ok_activate (GtkButton *, gpointer);
 void on_parameters_reset_activate (GtkButton *, gpointer);
 void on_parameters_entry_itermax_changed (GtkEntry *, gpointer );
 void on_parameters_entry_interpmax_changed (GtkEntry *, gpointer );
 void on_parameters_entry_errmax_changed (GtkEntry *, gpointer );
 void on_pi_parameters_quit_activate (GtkButton *, gpointer);
+void on_pi_parameters_destroy_activate (GtkWidget  *ww, gpointer data);
 void on_pi_parameters_ok_activate (GtkButton *, gpointer);
 void on_pi_parameters_reset_activate (GtkButton *, gpointer);
 void on_parameters_entry_epspi_changed(GtkButton *, gpointer);
@@ -130,6 +136,7 @@ void parameters_setup(void);
 void check_for_a_sparse(void);
 int examples_statusb_update(void);
 gint stop_computations(void);
+gboolean on_delete_event_do   (GtkWidget *, GdkEvent *, gpointer);
 
 /* prototypes help.c */
 void create_window_about(void);   
