@@ -422,7 +422,7 @@ if (committed.dimension_m > 250)
     gtk_statusbar_push(GTK_STATUSBAR(statusb_editb),0,"  Warning: Matrix Display is not accurate for dimensions larger then 250 x 250");
 
 /**************** connect signals  begin   */
-g_signal_connect ((gpointer) window_edit_b, "delete_event", G_CALLBACK (on_edit_b_menu_quit_activate),NULL);
+g_signal_connect ((gpointer) window_edit_b, "destroy", G_CALLBACK (on_edit_b_menu_destroy_activate),NULL);
 g_signal_connect ((gpointer) button_quit_ed, "clicked", G_CALLBACK(on_edit_b_menu_quit_activate),NULL);
 if (matvalueb!=NULL) { /* do not activate drawings calls if no memory for buffers */
                 g_signal_connect (G_OBJECT (matareab), "expose_event",  G_CALLBACK (draw_matareab_callback), NULL);
@@ -457,16 +457,31 @@ void
 on_edit_b_menu_quit_activate   (GtkMenuItem  *menuitem, gpointer  user_data)
 {
 if(is_debug==1) printf("on_edit_b_menu_quit_activate: quit\n");
+gtk_widget_destroy(GTK_WIDGET(window_edit_b));
+if(is_debug==1) printf("on_edit_b_menu_quit_activate: exiting \n");   
+}
+/*********************************/
+
+/* response to destroy window event */
+void
+on_edit_b_menu_destroy_activate   (GtkWidget  *ww, gpointer  user_data)
+{
+if(is_debug==1) printf("on_edit_b_menu_destroy_activate: \n");
+
 /* save block number */
 peb.block=b_displayed_block;
 /* free space of the graphic buffers */
-
+free(matvalueb);
+free(rgb_matvalueb);
+free(bs);
 is_edit_b_open=0;  /* 0=not open  1=open */
 gtk_widget_destroy(GTK_WIDGET(window_edit_b));
-if(is_debug==1) printf("on_edit_b_menu_quit_activate: exiting Edit B; preferences: %d %d %d %d %g %d\n",peb.block,peb.is_positive,peb.is_color,peb.is_user,peb.contrast_value,peb.is_range_type);   
+if(is_debug==1) printf("on_edit_b_menu_destroy_activate: exiting Edit B; preferences: %d %d %d %d %g %d\n",peb.block,peb.is_positive,peb.is_color,peb.is_user,peb.contrast_value,peb.is_range_type);
+
 }
 /*********************************/
 
+
 /* B block max */
 double
 bbmax(int q)
