@@ -31,8 +31,10 @@ void on_help_credits_clicked  (GtkButton       *button, gpointer         user_da
 void on_help_thanks_clicked  (GtkButton       *button, gpointer         user_data);
 
 /* prototypes callbacks.c */
-void on_help_closebutton_clicked   (GtkButton       *button, gpointer         user_data);
-void on_about_closebutton_clicked  (GtkButton       *button, gpointer         user_data);
+void on_help_closebutton_clicked   (GtkButton  *, gpointer );
+void on_help_destroy_activate   (GtkWidget *, gpointer );
+void on_about_closebutton_clicked  (GtkButton   *, gpointer );
+void on_about_destroy_activate   (GtkWidget *, gpointer );
 
 /* globals help.c */
 GtkTextBuffer *bufferm;
