@@ -58,7 +58,7 @@ create_window_main (void)
   GtkWidget *separator1;
   GtkWidget *separator2;
   GtkWidget *separator3;
-  GtkWidget *separator4;
+/*  GtkWidget *separator4;*/
   GtkWidget *separator5;
   GtkWidget *separator6;
   GtkWidget *separator7;
@@ -79,8 +79,11 @@ create_window_main (void)
   GtkWidget *saveu_m;
   GtkWidget *savepi_m;
   GtkWidget *savegru_m;
+/* telpack not to be available any more, so there is no point 
+ * in converting files in its formats 
   GtkWidget *import_telpack_m;
   GtkWidget *export_telpack_m; 
+*/
   GtkWidget *clear_notepad_m;
   GtkWidget *save_notepad_m;
   GtkWidget *quit_m;
@@ -303,7 +306,7 @@ create_window_main (void)
   separator3 =  gtk_separator_menu_item_new();
   gtk_widget_show(separator3);
   gtk_container_add (GTK_CONTAINER (menu_file), separator3);
-
+/*
   import_telpack_m = gtk_image_menu_item_new_with_label("Import Telpack");
   gtk_widget_show(import_telpack_m);
   gtk_container_add (GTK_CONTAINER (menu_file),import_telpack_m);
@@ -314,6 +317,7 @@ create_window_main (void)
   separator4 =  gtk_separator_menu_item_new();
   gtk_widget_show(separator4);
   gtk_container_add (GTK_CONTAINER (menu_file), separator4);
+*/
   clear_notepad_m = gtk_image_menu_item_new_with_label("Clear NotePad");
   gtk_widget_show(clear_notepad_m);
   gtk_container_add (GTK_CONTAINER (menu_file), clear_notepad_m); 
@@ -888,13 +892,13 @@ create_window_main (void)
   g_signal_connect ((gpointer) saveu_m, "activate", G_CALLBACK(on_main_menu_saveu_activate),NULL);
   g_signal_connect ((gpointer) savegru_m, "activate", G_CALLBACK(on_main_menu_savegru_activate),NULL);
   g_signal_connect ((gpointer) savepi_m, "activate", G_CALLBACK(on_main_menu_savepi_activate),NULL);
-  g_signal_connect ((gpointer) import_telpack_m, "activate", G_CALLBACK(on_main_menu_imptel_activate),NULL);
-  g_signal_connect ((gpointer) export_telpack_m, "activate", G_CALLBACK(on_main_menu_exptel_activate),NULL); 
+  /*g_signal_connect ((gpointer) import_telpack_m, "activate", G_CALLBACK(on_main_menu_imptel_activate),NULL);
+  g_signal_connect ((gpointer) export_telpack_m, "activate", G_CALLBACK(on_main_menu_exptel_activate),NULL); */
   g_signal_connect ((gpointer) clear_notepad_m, "activate", G_CALLBACK(on_main_menu_clearpad_activate),NULL);
   g_signal_connect ((gpointer) save_notepad_m, "activate", G_CALLBACK(on_main_menu_savepad_activate),NULL);
   g_signal_connect ((gpointer) quit_m, "activate", G_CALLBACK (on_main_menu_quit_activate), NULL); /* no use after enter_notify_event */
   g_signal_connect ((gpointer) quit_m, "button_press_event", G_CALLBACK (on_main_menu_quit_activate), NULL); /* use this instead */
-  g_signal_connect ((gpointer) window_main, "delete_event", G_CALLBACK (on_main_menu_quit_activate),NULL);
+  g_signal_connect ((gpointer) window_main, "destroy", G_CALLBACK (on_main_menu_destroy_activate),NULL);
    /*   testing poors man tooltips for menus  */
   g_signal_connect ((gpointer) quit_m, "enter_notify_event", G_CALLBACK (on_main_menu_quit_enter), NULL);
   g_signal_connect ((gpointer) quit_m, "leave_notify_event", G_CALLBACK (on_main_menu_quit_leave), NULL);
@@ -1383,8 +1387,7 @@ g_signal_connect ((gpointer) howmany_a_entry, "changed", G_CALLBACK (on_array_n_
 g_signal_connect ((gpointer) howmany_b_entry, "changed", G_CALLBACK (on_blocks_n_entry_changed), NULL);
 g_signal_connect ((gpointer) dimension_m_entry, "activate", G_CALLBACK (on_examples_ok_activate), NULL);
 g_signal_connect ((gpointer) dimension_n_entry, "activate", G_CALLBACK (on_examples_ok_activate), NULL);
-g_signal_connect ((gpointer) window_examples, "delete_event", G_CALLBACK (on_examples_quit_activate),NULL);
-g_signal_connect ((gpointer) window_examples, "destroy_event", G_CALLBACK (on_examples_quit_activate),NULL);
+g_signal_connect ((gpointer) window_examples, "destroy", G_CALLBACK (on_examples_destroy_activate),NULL);
 if(es[e_n].is_alpha==1) {
     g_signal_connect ((gpointer) alpha_entry , "activate", G_CALLBACK (on_examples_alpha_activate),NULL);
 /*
@@ -1545,7 +1548,7 @@ if((alg==1))   g_signal_connect ((gpointer) (GTK_COMBO (combo_interp))->entry,"c
 	gtk_widget_show (parameters_entry_errmax);
         gtk_box_pack_start (GTK_BOX (vbox_errmax),parameters_entry_errmax,FALSE, FALSE, 0);
 */
-g_signal_connect ((gpointer) window_parameters, "delete_event", G_CALLBACK (on_parameters_quit_activate),NULL);
+g_signal_connect ((gpointer) window_parameters, "destroy", G_CALLBACK (on_parameters_destroy_activate),NULL);
 g_signal_connect ((gpointer) cancel_button , "clicked", G_CALLBACK (on_parameters_quit_activate), NULL);
 g_signal_connect ((gpointer) ok_button , "clicked", G_CALLBACK (on_parameters_ok_activate), (gpointer)alg);
 g_signal_connect ((gpointer) reset_button , "clicked", G_CALLBACK (on_parameters_reset_activate),(gpointer)alg);
@@ -1639,7 +1642,7 @@ gtk_entry_set_editable(GTK_ENTRY(parameters_entry_epspi), FALSE);
 gtk_box_pack_start (GTK_BOX (vbox_epspi),combo_epspi,FALSE, FALSE, 0);
 
 
-g_signal_connect ((gpointer) window_pi_parameters, "delete_event", G_CALLBACK (on_pi_parameters_quit_activate),NULL);
+g_signal_connect ((gpointer) window_pi_parameters, "destroy", G_CALLBACK (on_pi_parameters_destroy_activate),NULL);
 g_signal_connect ((gpointer) cancel_button , "clicked", G_CALLBACK (on_pi_parameters_quit_activate), NULL);
 g_signal_connect ((gpointer) ok_button , "clicked", G_CALLBACK (on_pi_parameters_ok_activate), NULL);
 g_signal_connect ((gpointer) reset_button , "clicked", G_CALLBACK (on_pi_parameters_reset_activate),NULL);
