@@ -23,7 +23,9 @@ int lr_shift;
 int lr_gth;
 int fi_base0;
 int fi_base1;
+int fi_base_u;
 int fi_shift;
+int fi_shift_u;
 int fi_natural;
 int fi_traditional;
 int fi_Ubased;
@@ -65,6 +67,8 @@ int is_b;      /* 1= present 0=not present       */
 double alpha;    /* parameters used in some examples */
 double beta;
 int example;     /* 0 no example 1..9 examples */
+int fi_file_read; /* 0= a file for fi has not been read 1= has been read*/
+int fi_file_dim;  /* dimension of the file read - MUST be equal to dimension_m or it is not valid */
 struct algorithms_str alg;
 };
 
@@ -107,7 +111,7 @@ int eps;      /*lookup of the eps = epsilon(1.0d0) * 10 ** err */
 };
 
 struct edita_str {
-int block;              /* memory of block A last dispalyed */
+int block;              /* memory of block A or B last dispalyed */
 int is_gru;		/* 0=no 1=g 2=r 3=u */
 int is_positive;        /* 0: white is 0, black is 255; 1: white is 255, black is 0;  */
 int is_color;           /* =0 no color =1 color */
