@@ -445,7 +445,7 @@ view_image_compute();
 g_idle_add((GtkFunction) view_labels_update,NULL);
 
 /**************** connect signals  begin   */
-g_signal_connect ((gpointer) window_view, "delete_event", G_CALLBACK (on_view_menu_quit_activate),NULL);
+g_signal_connect ((gpointer) window_view, "destroy", G_CALLBACK (on_view_destroy_activate),NULL);
 g_signal_connect ((gpointer) button_quit_view, "clicked", G_CALLBACK(on_view_menu_quit_activate),NULL);
 g_signal_connect (G_OBJECT (view_area), "expose_event",  G_CALLBACK (draw_view_area_callback), NULL);
 g_signal_connect (G_OBJECT (view_area), "motion_notify_event",  G_CALLBACK (xy_view_area), NULL);
@@ -477,13 +477,21 @@ on_view_menu_quit_activate   (GtkMenuItem  *menuitem, gpointer  user_data)
 {
 if(is_debug==1) printf("on_view_menu_quit_activate: quit\n");
 gtk_widget_destroy(GTK_WIDGET(window_view));
+if(is_debug==1) printf("on_view_menu_quit_activate: exiting from View Matrix Window\n");   
+}
+/*********************************/
+
+/* View  Window: destroy activate **** Callback */
+void on_view_destroy_activate (GtkWidget  *ww, gpointer user_data )
+{
+if(is_debug==1) printf("on_view_menu_destroy_activate: about to free graphic buffers\n");
 /* free space of the graphic buffers */
 free(view_matvalue);
 free(rgb_view_matvalue);
 free(vrs);
 free(vcs);
 is_view_matrix_open=0;  /* 0=not open  1=open */
-if(is_debug==1) printf("on_view_menu_quit_activate: exiting from View Matrix Window\n");   
+if(is_debug==1) printf("on_view_menu_destroy_activate: done\n");
 }
 /*********************************/
 
@@ -1263,7 +1271,7 @@ GTK_WIDGET_SET_FLAGS (cancel_button, GTK_CAN_DEFAULT);
 
 /* GTK_RESPONSE_DELETE_EVENT */
 g_signal_connect ((gpointer) cancel_button, "clicked", G_CALLBACK (on_cancel_button_fsread_matrix_clicked), NULL);
-g_signal_connect ((gpointer) fileselection, "delete_event", G_CALLBACK (on_cancel_button_fsread_matrix_clicked),NULL);
+g_signal_connect ((gpointer) fileselection, "destroy", G_CALLBACK (on_destroy_fsread_matrix),NULL);
 g_signal_connect ((gpointer) ok_button,"clicked", G_CALLBACK (on_ok_button_fsread_matrix_clicked), NULL);
 
 return fileselection;
@@ -1276,13 +1284,20 @@ on_cancel_button_fsread_matrix_clicked      (GtkButton   * button, gpointer user
 {
 if(is_debug==1) printf("Read File Selection Dialog Matrix: quit\n");
 gtk_widget_destroy(gtk_widget_get_toplevel(GTK_WIDGET(button)));
+}
+/*********************************/
+
+/* Read  File Selection Dialog: destroy ***** Callback */
+void
+on_destroy_fsread_matrix      (GtkWidget   * ww, gpointer user_data )
+{
+if(is_debug==1) printf("Read File Selection Dialog Matrix: destroy\n");
 is_view_fs_open=0; /* now file selection is closed */
 view_fallback();
 }
-
-
 /*********************************/
 
+
 /* Read File Selection Dialog: ok ***** Callback    ONE ASCII FILE  */
 /* we look for an ASCII file containing a single square matrix, either matlab of fortran style */
 /* some integers at the beginning are clues for dimension in fortran style */
